.. hckr documentation master file, created by
   sphinx-quickstart on Wed Jun 12 20:06:39 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. important::
     ``DEFAULT`` config is the parent of all other configurations and others will inherit its values if not overridden

.. click:: hckr.cli.config:config
   :prog: hckr config
   :nested: full
